@@ -133,8 +133,7 @@ class Event(object):
                 vevents['PROTO'] = event
 
         if ref is None:
-            ref = 'PROTO'
-
+            ref = 'PROTO' if ref in vevents.keys() else list(vevents.keys())[0]
         try:
             if type(vevents[ref]['DTSTART'].dt) != type(vevents[ref]['DTEND'].dt):  # flake8: noqa
                 raise ValueError('DTSTART and DTEND should be of the same type (datetime or date)')
